@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::SOAP::Client;
 use vars '$VERSION';
-$VERSION = '3.08';
+$VERSION = '3.09';
 
 
 use Log::Report 'xml-compile-soap', syntax => 'SHORT';
@@ -96,7 +96,7 @@ sub compileClient(@)
           , sub { $callback->($output_handler->(@_)) }
           );
       }
-    : sub # Synchronous call (f.i. XML::Compile::Transfer::SOAPHTTP
+    : sub # Synchronous call, f.i. XML::Compile::Transfer::SOAPHTTP
       { my ($data, $charset)
           = UNIVERSAL::isa($_[0], 'HASH') ? @_
           : @_%2==0 ? ({@_}, undef)
